spoon.messaging.SingletonMessaging

Package spoon :: Package messaging :: Class SingletonMessaging |
[show private | hide private]
[frames | no frames]

## Type SingletonMessaging

    object --+
             |
     Messaging --+
                 |
                SingletonMessaging

For convinience this is a singleton version of the Messaging system. This can be used when the node will only have one Messaging system throughout the life of the process. Furthermore, if this is the case you can use the function/static method decorator acceptMsg with this.

Method Summary
| `getinstance()` (Static method)
| `hasinstance()` (Static method)
Inherited from Messaging
| ``__init__`(self, network)`
| ``handleMessage`(self, src, msg)` Calls the all handlers for the given message.
| ``registerHandler`(self, msgtype, handler)`
| ``send`(self, dst, messageStr, obj)` Sends a Messaging message (not just a NetMessage) to the destination node.
| ``setNetwork`(self, network)`
| ``unregisterHandler`(self, msgtype, handler)`
Inherited from object
| ``__delattr__`(...)` x.__delattr__('name') <==> del x.name
| ``__getattribute__`(...)` x.__getattribute__('name') <==> x.name
| ``__hash__`(x)` x.__hash__() <==> hash(x)
| ``__new__`(T, S, ...)` T.__new__(S, ...) -> a new object with type S, a subtype of T
| ``__reduce__`(...)` helper for pickle
| ``__reduce_ex__`(...)` helper for pickle
| ``__repr__`(x)` x.__repr__() <==> repr(x)
| ``__setattr__`(...)` x.__setattr__('name', value) <==> x.name = value
| ``__str__`(x)` x.__str__() <==> str(x)

Class Variable Summary
`NoneType` | `singleton` = None

Class Variable Details

    ### singleton Type: `NoneType` Value:
        None

Generated by Epydoc 2.1 on Sun Nov 26 15:33:08 2006 | http://epydoc.sf.net